DOWNLOADDIR="/home/${USER}/gisdata/"
UNZIPTOOL=unzip
WGETTOOL="/usr/bin/wget"
export PGBIN=/usr/pgsql-9.3/bin
PSQL="${PGBIN}/psql --dbname=geocoder --username=postgres"
SHP2PGSQL=${PGBIN}/shp2pgsql

if ! [ -d $DOWNLOADDIR ]; then
    mkdir $DOWNLOADDIR
fi
if ! [ -d $DOWNLOADDIR/tmp ]; then
    mkdir $DOWNLOADDIR/tmp
fi

cd $DOWNLOADDIR
wget ftp://ftp2.census.gov/geo/tiger/TIGER2013/STATE/ --no-parent --relative --recursive --level=1 --accept=zip --mirror --reject=html
cd $DOWNLOADDIR/ftp2.census.gov/geo/tiger/TIGER2013/STATE
rm -f ${DOWNLOADDIR}/tmp/*.*
${PSQL} -c "DROP SCHEMA IF EXISTS tiger_staging CASCADE;"
${PSQL} -c "CREATE SCHEMA tiger_staging;"
for z in tl_*state.zip ; do $UNZIPTOOL -o -d $DOWNLOADDIR/tmp $z; done
cd $DOWNLOADDIR/tmp;

${PSQL} -c "CREATE TABLE tiger_data.state_all(CONSTRAINT pk_state_all PRIMARY KEY (statefp),CONSTRAINT uidx_state_all_stusps  UNIQUE (stusps), CONSTRAINT uidx_state_all_gid UNIQUE (gid) ) INHERITS(state); "
${SHP2PGSQL} -c -s 4269 -g the_geom   -W "latin1" tl_2013_us_state.dbf tiger_staging.state | ${PSQL}
${PSQL} -c "SELECT loader_load_staged_data(lower('state'), lower('state_all')); "
${PSQL} -c "CREATE INDEX tiger_data_state_all_the_geom_gist ON tiger_data.state_all USING gist(the_geom);"
${PSQL} -c "VACUUM ANALYZE tiger_data.state_all"
cd $DOWNLOADDIR
wget ftp://ftp2.census.gov/geo/tiger/TIGER2013/COUNTY/ --no-parent --relative --recursive --level=1 --accept=zip --mirror --reject=html
cd $DOWNLOADDIR/ftp2.census.gov/geo/tiger/TIGER2013/COUNTY
rm -f $DOWNLOADDIR/tmp/*.*
${PSQL} -c "DROP SCHEMA IF EXISTS tiger_staging CASCADE;"
${PSQL} -c "CREATE SCHEMA tiger_staging;"
for z in tl_*county.zip ; do $UNZIPTOOL -o -d $DOWNLOADDIR/tmp $z; done
cd $DOWNLOADDIR/tmp;

${PSQL} -c "CREATE TABLE tiger_data.county_all(CONSTRAINT pk_tiger_data_county_all PRIMARY KEY (cntyidfp),CONSTRAINT uidx_tiger_data_county_all_gid UNIQUE (gid)  ) INHERITS(county); "
${SHP2PGSQL} -c -s 4269 -g the_geom   -W "latin1" tl_2013_us_county.dbf tiger_staging.county | ${PSQL}
${PSQL} -c "ALTER TABLE tiger_staging.county RENAME geoid TO cntyidfp;  SELECT loader_load_staged_data(lower('county'), lower('county_all'));"
${PSQL} -c "CREATE INDEX tiger_data_county_the_geom_gist ON tiger_data.county_all USING gist(the_geom);"
${PSQL} -c "CREATE UNIQUE INDEX uidx_tiger_data_county_all_statefp_countyfp ON tiger_data.county_all USING btree(statefp,countyfp);"
${PSQL} -c "CREATE TABLE tiger_data.county_all_lookup ( CONSTRAINT pk_county_all_lookup PRIMARY KEY (st_code, co_code)) INHERITS (county_lookup);"
${PSQL} -c "VACUUM ANALYZE tiger_data.county_all;"
${PSQL} -c "INSERT INTO tiger_data.county_all_lookup(st_code, state, co_code, name) SELECT CAST(s.statefp as integer), s.abbrev, CAST(c.countyfp as integer), c.name FROM tiger_data.county_all As c INNER JOIN state_lookup As s ON s.statefp = c.statefp;"
${PSQL} -c "VACUUM ANALYZE tiger_data.county_all_lookup;"

